import { draggable } from "@atlaskit/pragmatic-drag-and-drop/element/adapter";
import { Children, cloneElement, useEffect, useRef, useState } from "react";
function getPositionFromArgs(args, offset, scale) {
  const { clientX, clientY } = args.location.current.input;
  const { element } = args.source;
  const offsetParent = element.offsetParent ?? element.ownerDocument.body;
  const offsetParentRect = offsetParent.getBoundingClientRect();
  const x = (clientX - offset.x + offsetParent.scrollLeft - offsetParentRect.left) / scale;
  const y = (clientY - offset.y + offsetParent.scrollTop - offsetParentRect.top) / scale;
  return { x, y };
}
function Draggable(props) {
  const { children, disabled, onDrag, onStop, onStart, scale = 1 } = props;
  const [isDragging, setIsDragging] = useState(false);
  const rChild = useRef(null);
  const rLast = useRef({});
  const rDelta = useRef({ x: 0, y: 0 });
  const rOffset = useRef({ x: 0, y: 0 });
  useEffect(() => {
    const handleDragStart = (args) => {
      const { clientX, clientY } = args.location.current.input;
      const { element: element2 } = args.source;
      const elRect = element2.getBoundingClientRect();
      rOffset.current = {
        x: clientX - elRect.left,
        y: clientY - elRect.top
      };
      const { x, y } = getPositionFromArgs(args, rOffset.current, scale);
      const data = {
        node: element2,
        x,
        y,
        deltaX: rDelta.current.x,
        deltaY: rDelta.current.y
      };
      rLast.current = { x, y };
      setIsDragging(true);
      onStart?.(data);
    };
    const handleDrag = (args) => {
      const { element: element2 } = args.source;
      const { x, y } = getPositionFromArgs(args, rOffset.current, scale);
      rDelta.current = {
        x: x - (rLast.current.x ?? 0),
        y: y - (rLast.current.y ?? 0)
      };
      const data = {
        node: element2,
        x,
        y,
        deltaX: rDelta.current.x,
        deltaY: rDelta.current.y,
        lastX: rLast.current.x,
        lastY: rLast.current.y
      };
      rLast.current = { x, y };
      if (rDelta.current.x === 0 && rDelta.current.y === 0) return;
      onDrag?.(data);
    };
    const handleDrop = (args) => {
      const { element: element2 } = args.source;
      const { x, y } = getPositionFromArgs(args, rOffset.current, scale);
      rDelta.current = {
        x: x - (rLast.current.x ?? 0),
        y: y - (rLast.current.y ?? 0)
      };
      const data = {
        node: element2,
        x,
        y,
        deltaX: rDelta.current.x,
        deltaY: rDelta.current.y,
        lastX: rLast.current.x,
        lastY: rLast.current.y
      };
      rLast.current = {};
      rOffset.current = { x: 0, y: 0 };
      setIsDragging(false);
      onStop?.(data);
    };
    const element = rChild.current;
    if (!element) return;
    return draggable({
      element,
      canDrag: () => !disabled,
      onDragStart: handleDragStart,
      onDrag: handleDrag,
      onDrop: handleDrop
    });
  }, [disabled, onStart, onDrag, onStop, scale]);
  useEffect(() => {
    const handleDragOver = (e) => {
      e.preventDefault();
      if (!e.dataTransfer) return;
      e.dataTransfer.dropEffect = "move";
    };
    if (!isDragging) return;
    const parentEl = rChild.current?.ownerDocument?.body;
    if (!parentEl) return;
    parentEl.addEventListener("dragover", handleDragOver);
    return () => parentEl.removeEventListener("dragover", handleDragOver);
  }, [isDragging]);
  return cloneElement(Children.only(children), {
    ref: rChild
  });
}
export {
  Draggable
};
//# sourceMappingURL=Draggable.js.map
