import { useCallback, useMemo, useState } from "react";
import { calculateMasonryItemSize } from "../utils/calculateMasonryItemSize.js";
import { calculateMasonryItemXY } from "../utils/calculateMasonryItemXY.js";
import { clamp } from "../utils/clamp.js";
import { clsx } from "../utils/clsx.js";
import { getGridColumnWidth } from "../utils/getGridColumnWidth.js";
import { getMasonryItemPosition } from "../utils/getMasonryItemPosition.js";
import { getMasonryItemStyle } from "../utils/getMasonryItemStyle.js";
function useMasonryItemState(props) {
  const {
    className: inClassName,
    columns,
    containerPadding,
    containerWidth,
    height,
    id,
    isBounded,
    isDraggable,
    isStatic,
    margin,
    maxRows,
    onDrag,
    onDragStart,
    onDragStop,
    rowHeight,
    transformScale,
    width,
    x,
    y
  } = props;
  const [isDragging, setIsDragging] = useState(false);
  const positionParams = useMemo(
    () => ({
      columns,
      containerPadding,
      containerWidth,
      margin,
      maxRows,
      rowHeight
    }),
    [columns, containerPadding, containerWidth, margin, maxRows, rowHeight]
  );
  const handleDragStart = useCallback(
    (data) => {
      if (!onDragStart) return;
      const { node } = data;
      const newPosition = { top: 0, left: 0 };
      const { offsetParent } = node;
      if (!offsetParent) return;
      const parentRect = offsetParent.getBoundingClientRect();
      const clientRect = node.getBoundingClientRect();
      const clientLeft = clientRect.left / transformScale;
      const parentLeft = parentRect.left / transformScale;
      const clientTop = clientRect.top / transformScale;
      const parentTop = parentRect.top / transformScale;
      newPosition.left = clientLeft - parentLeft + offsetParent.scrollLeft;
      newPosition.top = clientTop - parentTop + offsetParent.scrollTop;
      const { x: x2, y: y2 } = calculateMasonryItemXY(positionParams, newPosition.top, newPosition.left, width, height);
      setIsDragging(true);
      onDragStart(id, x2, y2);
    },
    [onDragStart, transformScale, positionParams, width, height, id]
  );
  const handleDrag = useCallback(
    (data) => {
      if (!onDrag) return;
      const { node, deltaX, deltaY } = data;
      let top = data.y;
      let left = data.x;
      if (isBounded) {
        const { offsetParent } = node;
        if (offsetParent) {
          const bottomBoundary = offsetParent.clientHeight - calculateMasonryItemSize(height, rowHeight, margin[1]);
          top = clamp(top, 0, bottomBoundary);
          const columnWidth = getGridColumnWidth(positionParams);
          const rightBoundary = containerWidth - calculateMasonryItemSize(width, columnWidth, margin[0]);
          left = clamp(left, 0, rightBoundary);
        }
      }
      const newPosition = { top, left };
      const { x: x2, y: y2 } = calculateMasonryItemXY(positionParams, top, left, width, height);
      return onDrag(id, x2, y2);
    },
    [isBounded, positionParams, containerWidth, margin, rowHeight, width, height, onDrag, id]
  );
  const handleDragStop = useCallback(
    (data) => {
      if (!onDragStop) return;
      const { x: x2, y: y2 } = calculateMasonryItemXY(positionParams, data.y, data.x, width, height);
      setIsDragging(false);
      return onDragStop(id, x2, y2);
    },
    [onDragStop, positionParams, width, height, id]
  );
  const style = getMasonryItemStyle(getMasonryItemPosition(positionParams, x, y, width, height));
  const className = clsx("react-grid-item", "cssTransforms", inClassName, {
    static: isStatic,
    "react-draggable": isDraggable,
    "react-draggable-dragging": Boolean(isDragging)
  });
  return {
    className,
    handleDragStart,
    handleDrag,
    handleDragStop,
    isDraggable,
    style,
    transformScale
  };
}
export {
  useMasonryItemState
};
//# sourceMappingURL=useMasonryItemState.js.map
